pub fn provide_root_context<T: Clone + 'static>(value: T)Expand description
Store the given value in the root scope.
Only needed for specific cases like values consumed by queries or mutations, which run in the root scope. Prefer provide_context otherwise.